0.0.30
Se actualiza función **color message**
0.0.31
Se actualiza función **footer_signature_html**
Se crea nueva funcion get_data_resources y get_data_cache (no se implementa por el momento), y se cambia el nombre de la funcion full_read_excel por set_resources
0.0.32
Se actualiza footer_signature_html
0.0.33
Se actualiza footer_signature_html nuevamente por diferencias en el color del equipo y espacios entre integrantes
